Skip to contents

Checks if the specified directory exists, and creates the directory path if necessary.

Usage

create_directory(path)

Arguments

path

A character string specifying the directory path.

Value

None. The function creates a directory as a side effect.

Examples

test_dir <- "data/test_dir"
create_directory(test_dir)