R/create_directory.R
create_directory.Rd
Checks if the specified directory exists, and creates the directory path if necessary.
create_directory(path)
A character string specifying the directory path.
None. The function creates a directory as a side effect.
test_dir <- "data/test_dir" create_directory(test_dir)